@@ -1,22 +1,21 @@
 """
 Reverse engineering of Google Bard
 """
+import argparse
 import json
 import random
-import string
-import requests
 import re
-import argparse
+import string
 
+import requests
 from prompt_toolkit import prompt
 from prompt_toolkit import PromptSession
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.completion import WordCompleter
 from prompt_toolkit.history import InMemoryHistory
 from prompt_toolkit.key_binding import KeyBindings
-
-from rich.markdown import Markdown
 from rich.console import Console
+from rich.markdown import Markdown
 
 
 def create_session() -> PromptSession:
@@ -116,7 +115,7 @@ class Chatbot:
             "conversation_id": json_chat_data[1][0],
             "response_id": json_chat_data[1][1],
             "factualityQueries": json_chat_data[3],
-            "textQuery": json_chat_data[2][0],
+            "textQuery": json_chat_data[2][0] if json_chat_data[2] is not None else "",
             "choices": [{"id": i[0], "content": i[1]} for i in json_chat_data[4]],
         }
         self.conversation_id = results["conversation_id"]
@@ -133,20 +132,26 @@ if __name__ == "__main__":
         Repo: github.com/acheong08/Bard
 
         Enter `alt+enter` or `esc+enter` to send a message.
-        """
+        """,
     )
     parser = argparse.ArgumentParser()
     parser.add_argument(
-        "--session", help="__Secure-1PSID cookie.", type=str, required=True
+        "--session",
+        help="__Secure-1PSID cookie.",
+        type=str,
+        required=True,
     )
     parser.add_argument(
-        "--at", help="window.WIZ_global_data.SNlM0e", type=str, required=True
+        "--at",
+        help="window.WIZ_global_data.SNlM0e",
+        type=str,
+        required=True,
     )
     args = parser.parse_args()
 
     chatbot = Chatbot(args.session, args.at)
     prompt_session = create_session()
-    completions = create_completer(["!exit"])
+    completions = create_completer(["!exit", "!reset"])
     console = Console()
     try:
         while True:
@@ -155,6 +160,11 @@ if __name__ == "__main__":
             console.print()
             if user_prompt == "!exit":
                 break
+            elif user_prompt == "!reset":
+                chatbot.conversation_id = ""
+                chatbot.response_id = ""
+                chatbot.choice_id = ""
+                continue
             print("Google Bard:")
             response = chatbot.ask(user_prompt)
             console.print(Markdown(response["content"]))
